@@ -2,7 +2,8 @@ from dragonfly.room2d import Room2D
 from dragonfly.story import Story
 from dataclasses import dataclass
 from typing import List
-from .utils import short_name
+from .utils import short_name, lower_left_properties
+from dragonfly.windowparameter import RectangularWindows
 
 
 @dataclass
@@ -41,7 +42,7 @@ class Slab:
                f'   CONSTRUCTION    = "{self.construction}_c"\n' \
                f'   LOCATION        = {self.type_adjacency}\n   ..'
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.to_inp()
 
 
@@ -88,7 +89,92 @@ class RoofCeiling:
                f'   CONSTRUCTION    = "{self.construction}_c"\n' \
                f'   LOCATION        = TOP\n   ..'
 
-    def __repr__(self):
+    def __repr__(self) -> str:
+        return self.to_inp()
+
+
+@dataclass
+class Window:
+    """*.inp Window object.
+
+        Args:
+            name: display name of the room2d, to be added to, creating a unique displayname.
+            location: the index/n of the window in the set of windows hosted by the wall
+            segment.
+            x: window origin pt.x coord.
+            y: window origin pt.y coord.
+            width: window width.
+            height: window height.
+
+    Example:
+        .. code-block:: f#
+
+            rmOne_wndw_0_wall1 = WINDOW
+                X           = 0.6830601092896195
+                Y           = 2.6229508196721314
+                WIDTH       = 9.562841530054643
+                HEIGHT      = 6.557377049180327
+                GLASS-TYPE  = WT1
+                ..
+    """
+    name: str
+    location: int
+    x: float
+    y: float
+    width: float
+    height: float
+
+    def to_inp(self):
+        return f'{self.name}_wall{self.location} = WINDOW\n   ' \
+               f'X           = {self.x}\n   ' \
+               f'Y           = {self.y}\n   ' \
+               f'WIDTH       = {self.width}\n   ' \
+               f'HEIGHT      = {self.height}\n   '\
+               f'GLASS-TYPE  = WT1\n   ..\n'
+
+    def __repr__(self) -> str:
+        return self.to_inp()
+
+
+@dataclass
+class WindowSet:
+    """ An internal object comprising all of the windows hosted by a wall segment.
+
+        Init methods(s):
+            from_params(name, location, rectangular_window_params).
+
+        Args:
+            name: the display name of the room2d hosting the wall the windowset belongs to.
+            location: the index of the room2D's wall segment hosting the window set. for use on
+            creating unique identifier name for each window.
+            windows: list of Window objects comprising the window set.
+
+
+    """
+    name: str
+    location: int
+    windows: List[Window]
+
+    @classmethod
+    def from_params(cls, name: str, location: int,
+                    rectangular_window_params: RectangularWindows):
+        origins = [(orig.x, orig.y) for orig in rectangular_window_params.origins]
+        widths = rectangular_window_params.widths
+        heights = rectangular_window_params.heights
+
+        windows = []
+        for i, (org, w, h) in enumerate(zip(origins, widths, heights)):
+            windows.append(
+                Window(
+                    f'{name}_wndw_{i}', location + 1, org[0],
+                    org[1],
+                    w, h))
+        return cls(name=name, location=location + 1, windows=windows)
+
+    def to_inp(self):
+        return '\n'.join([wndw.to_inp() for wndw in self.windows])
+
+    def __repr__(self) -> str:
         return self.to_inp()
 
 
@@ -117,16 +203,27 @@ class Wall:
     name: str
     location: int
     construction: str
+    windows: RectangularWindows = None
 
     @classmethod
-    def from_room_seg(cls, name: str, location: int, construction: str):
+    def from_room_seg(cls, name: str, location: int, construction: str,
+                      windows: None):
         indexed_id = location + 1
-        return cls(f'{name}_Wall_{indexed_id}', indexed_id, construction)
+        return cls(f'{name}_Wall_{indexed_id}', indexed_id, construction, windows)
 
     def to_inp(self):
-        return f'"{self.name}" = EXTERIOR-WALL\n' \
-            f'   CONSTRUCTION    = "{self.construction}_c"\n' \
-            f'   LOCATION        = SPACE-V{self.location}\n   ..'
+        wallstr = f'"{self.name}" = EXTERIOR-WALL\n' \
+                  f'   CONSTRUCTION    = "{self.construction}_c"\n' \
+                  f'   LOCATION        = SPACE-V{self.location}\n   ..'
+
+        if self.windows is not None:
+            window_set = WindowSet.from_params(
+                self.name, self.location, self.windows)
+            wall_set = [wallstr]
+            wall_set.append(window_set.to_inp())
+            return '\n'.join(wall_set)
+        else:
+            return wallstr
 
     def __repr__(self) -> str:
         return self.to_inp()
@@ -177,15 +274,19 @@ class Space:
                 f'Unsupported Type: {type(room)}.\n'
                 'Expected dragonfly.room2d.Room2D'
             )
-
         wall_constr_name = short_name(
             room.properties.energy.construction_set.wall_set.exterior_construction.display_name, 30)
         name = room.display_name
-        walls = [
-            Wall.from_room_seg(name, i, wall_constr_name)
-            for i, bc in enumerate(room.boundary_conditions)
-            if str(bc) == 'Outdoors'
-        ]
+
+        low_l_props = lower_left_properties(room)
+        bcs = low_l_props[1]
+        wndw_paras = low_l_props[2]
+
+        walls = []
+        for i, (bc, window_param) in enumerate(zip(bcs, wndw_paras)):
+            if str(bc) == 'Outdoors':
+                walls.append(Wall.from_room_seg(name, i, wall_constr_name, window_param))
+
         slab = None if room.is_ground_contact != True else Slab.from_room(name, short_name(
             room.properties.energy.construction_set.floor_set.ground_construction.display_name, 30))
 
@@ -209,7 +310,7 @@ class Space:
             blocks.append(self.roof.to_inp())
         return '\n'.join(blocks)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.to_inp()
 
 
@@ -275,5 +376,5 @@ class Floor:
         flr_spcs = '\n'.join(spc.to_inp() for spc in self.spaces)
         return '\n'.join([flr_str, flr_spcs])
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.to_inp()
