@@ -36,12 +36,13 @@ class Model:
         df_model.convert_to_units(units='Feet')
 
         polygons = []
-        flr_spc = [Floor.from_story(story) for story in df_model.stories]
-
-        for story in df_model.stories:
-            polygons.append(Polygon.from_story(story))
-            for room in story:
-                polygons.append(Polygon.from_room(room))
+        flr_spc = []
+        for building in df_model.buildings:
+            for story in building.all_stories():
+                flr_spc.append(Floor.from_story(story))
+                polygons.append(Polygon.from_story(story))
+                for room in story:
+                    polygons.append(Polygon.from_room(room))
 
         constructions = ConstructionCollection.from_hb_constructions(
             df_model.properties.energy.constructions)
@@ -135,6 +136,8 @@ class Model:
             self.compliance_data.to_inp(),
             self.site_bldg_data.to_inp(),
             self.constructions.to_inp(),
+            fb.glzCode,
+            fb.glzTyp,
             fb.polygons,
             '\n'.join(pl.to_inp() for pl in self.polygons),
             fb.wallParams,
